@@ -33,13 +33,13 @@ use strict;
 
 package Finance::Quote::TSP;
 
-use vars qw($VERSION $TSP_URL $TSP_MAIN_URL %TSP_FUND_COLUMNS %TSP_FUND_NAMES);
+use vars qw( $TSP_URL $TSP_MAIN_URL %TSP_FUND_COLUMNS %TSP_FUND_NAMES);
 
 use LWP::UserAgent;
 use HTTP::Request::Common;
 use HTML::TableExtract;
 
-$VERSION = '1.18';
+our $VERSION = '1.47'; # VERSION
 
 # URLs of where to obtain information
 
@@ -98,7 +98,7 @@ sub tsp {
 	$ua = $quoter->user_agent;
 	$reply = $ua->request(GET $TSP_URL);
 	return unless ($reply->is_success);
-	$te = new HTML::TableExtract( headers =>
+	$te = HTML::TableExtract->new( headers =>
 		["Date", values %TSP_FUND_COLUMNS] );
 
 	$te->parse($reply->content);
